//This file is part of Furius Iso Mount. Copyright 2008 Dean Harris (marcus_furius@hotmail.com)
//
//    Furius Iso Mount is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    Furius Iso Mount is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Furius Iso Mount.  If not, see <http://www.gnu.org/licenses/>.

using System;
using System.IO;
using Gtk;
using System.Reflection;

namespace FuriusIsoMount
{
	
	/// <summary>
    /// Helper class for the Gtk.AboutDialog
    /// </summary>
	/// <remarks>
	/// This class relies on the presence of an AssemblyInfo class
	/// and a resource called gpl.txt.
	/// </remarks>
	public static class AboutBox
	{
				
		/// <summary>
        /// Shows an about box
        /// </summary>
		/// <param name="logo">An application logo</param>
		public static void Show(Gdk.Pixbuf logo)
		{
			
			AboutDialog dialog = new AboutDialog();
			if (logo != null)
			{
				dialog.Logo = logo;
			}
			dialog.ProgramName = ApplicationTitle;
			dialog.Version = ApplicationVersion;
			dialog.Comments = LocalizableResources.ApplicationDescription;
			dialog.Website = ApplicationCompany;
			dialog.TranslatorCredits = Translators;
			dialog.Authors = Authors;
			dialog.License = Licence;
			dialog.Run ();
			dialog.Destroy ();      
		}
			
		/// <summary>
        /// Gets the application title.
        /// </summary>
        /// <value>The application title.</value>
        public static string ApplicationTitle
        {
            get
            {

                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyTitleAttribute), false);
				if (attributes.Length > 0)
                {
					AssemblyTitleAttribute titleAttribute = (AssemblyTitleAttribute)attributes[0];
                    if (titleAttribute.Title != string.Empty)
                    {
                        return titleAttribute.Title;
                    }
                }
                return System.IO.Path.GetFileNameWithoutExtension(Assembly.GetExecutingAssembly().CodeBase);
            }
        }
		
		/// <summary>
        /// Gets the application version.
        /// </summary>
        /// <value>The application version.</value>
        public static string ApplicationVersion
        {
            get
            {
                return Assembly.GetExecutingAssembly().GetName().Version.ToString();
            }
        }
		
		/// <summary>
        /// Gets the application description.
        /// </summary>
        /// <value>The application description.</value>
        public static string ApplicationDescription
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyDescriptionAttribute), false);
                if (attributes.Length == 0)
                {
                    return "";
                }
                return ((AssemblyDescriptionAttribute)attributes[0]).Description;
            }
        }
		
		/// <summary>
        /// Gets the application company.
        /// </summary>
        /// <value>The application company.</value>
        public static string ApplicationCompany
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyCompanyAttribute), false);
                if (attributes.Length == 0)
                {
                    return "";
                }
                return ((AssemblyCompanyAttribute)attributes[0]).Company;
            }
        }
		
		/// <summary>
        /// Gets the application licence.
        /// </summary>
        /// <value>The application licence.</value>
		public static string Licence
		{
			get
			{
				try
				{
					using(Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream("gpl.txt"))	
					{
						using(StreamReader streamReader = new StreamReader(stream))
						{
							return streamReader.ReadToEnd();
						}
					}
				}
				catch //Bad form, I know!
				{
					return string.Empty;
				}
			}
		}

		/// <summary>
        /// Gets the application authors.
        /// </summary>
        /// <value>The application authors.</value>
		public static string[] Authors 
		{
			get 
			{
				string[] authors = {string.Format
					("{0}:{1}    Dean Harris <marcus_furius@hotmail.com>", 
					 LocalizableResources.AuthorDeveloper, Environment.NewLine)};
				return authors;
			}
		}
		
		/// <summary>
        /// Gets the application translators.
        /// </summary>
        /// <value>The application translators.</value>
		public static string Translators 
		{
			get 
			{
				string translators = string.Format
					("(de-DE):{0}    Vinzenz Vietzke <vinz@v1nz.de>{0} (es-ES):{0}    Andrew Leigh", 
					  Environment.NewLine);
				return translators;
			}
		}
	}
}
