//This file is part of Furius Iso Mount. Copyright 2008 Dean Harris (marcus_furius@hotmail.com)
//
//    Furius Iso Mount is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    Furius Iso Mount is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with Furius Iso Mount.  If not, see <http://www.gnu.org/licenses/>.
using System;

namespace FuriusIsoMount
{
	
	/// <summary>
	/// Static Class with functions and properties accessed globally
	/// </summary>
	public static class Globals
	{
		private static string homeDirectory = Environment.GetFolderPath(Environment.SpecialFolder.Personal) + "/";
		private static string mountLog = Environment.GetFolderPath(Environment.SpecialFolder.Personal) +  
				                       "/.FuriusIsoMount/FuriusMountLog.txt";		
		private static string mountList = Environment.GetFolderPath(Environment.SpecialFolder.Personal) +  
				                       "/.FuriusIsoMount/FuriusMountList.csv";
		private static string historyList = Environment.GetFolderPath(Environment.SpecialFolder.Personal) +  
				                       "/.FuriusIsoMount/FuriusMountHistory.txt";
		private static int imageHistoryMaximum = 10;
		
		/// <value>
		/// Returns the users Home directory
		/// </value>		
		public static string HomeDirectory 
		{
			get 
			{
				return homeDirectory;
			}
		}

		/// <value>
		/// Returns the path of the Mount Log
		/// </value>
		public static string MountLog 
		{
			get 
			{
				return mountLog;
			}
		}

		/// <value>
		/// Returns the number of images to staore in the history
		/// </value>
		public static int ImageHistoryMaximum 
		{
			get 
			{
				return imageHistoryMaximum;
			}
		}
			
		/// <value>
		/// Returns the path of the Mount List use to store mounted images on close
		/// </value>
		public static string MountList 
		{
			get 
			{
				return mountList;
			}
		}

		/// <value>
		/// Returns the path of the History List
		/// </value>
		public static string HistoryList 
		{
			get 
			{
				return historyList;
			}
		}
		
		/// <summary>
		/// The InsertIntoArray method accepts three parameters. 
		/// The first parameter, target, is the array that is to have an element added; 
		/// value is the element to be added; and index is the zero-based position at which value is to be added. 
		/// Elements at and above the inserted element are shifted up by one. The last element in the array is discarded.
		/// </summary>
		/// <param name="target">A <see cref="Array"/></param>
		/// <param name="value">A <see cref="System.Object"/></param>
		/// <param name="index">A <see cref="System.Int32"/></param>
		public static void InsertIntoArray(Array target, object value, int index) 
        { 
            if (index < target.GetLowerBound(0) || 
                index > target.GetUpperBound(0)) 
            { 
                throw (new ArgumentOutOfRangeException("index", index, 
                    "Array index out of bounds.")); 
            } 
            else 
            { 
                Array.Copy(target, index, target, index + 1, 
                        target.Length - index - 1); 
            } 
            target.SetValue(value, index); 
        }
		
		/// <summary>
		/// The RemoveFromArray method accepts two parameters. 
		/// target is the array from which an element is to be removed; 
		/// the second parameter, index, is the zero-based position of the element to be removed in the array. 
		/// Elements at and above the inserted element are shifted down by one. 
		/// The last element in the array is set to the default value for the array type. 
		/// </summary>
		/// <param name="target">A <see cref="Array"/></param>
		/// <param name="index">A <see cref="System.Int32"/></param>
		public static void RemoveFromArray(Array target, int index) 
        { 
            if (index < target.GetLowerBound(0) || 
                index > target.GetUpperBound(0)) 
            { 
                throw (new ArgumentOutOfRangeException("index", index, 
                    "Array index out of bounds.")); 
            } 
            else if (index < target.GetUpperBound(0)) 
            { 
                Array.Copy(target, index + 1, target, index, 
                        target.Length - index - 1); 
            } 
            target.SetValue(null, target.GetUpperBound(0)); 
        } 
	}
}
